import config from './config';
import AudioRecord from 'react-native-audio-record';
import { Buffer } from 'buffer';

const options = {
  sampleRate: 16000,  // default 44100
  channels: 1,        // 1 or 2, default 1
  bitsPerSample: 16,  // 8 or 16, default 16
  audioSource: 6,     // android only (see below)
  wavFile: 'test.wav' // default 'audio.wav'
};

class ASRserviceClass {
  host: any;
  responseErrorText: any;
  api_id: string;
  api_key: string;
  endpoint: string;
  chunk: any;
  lang: string;

  constructor() {
    this.host = config.ASR.host;
    this.endpoint = config.ASR.endpoint;
    this.api_id = config.ASR.api_id;
    this.api_key = config.ASR.api_key;
    this.chunk = [];
    this.lang = 'eu';
    AudioRecord.init(options);
  }

  startStream() {
    AudioRecord.start();
    AudioRecord.on('data', data => {
      var chunk = Buffer.from(data, 'base64');
      this.chunk.push(chunk)
    });
  }
  
  stopStream() {
    AudioRecord.stop();
    return this.sendToApi(Buffer.concat(this.chunk))
  }

  async sendToApi(data: any) {
    return new Promise((resolve, reject) => {
      fetch(`${this.host}${this.lang}${this.endpoint}`, {
        method: 'post',
        headers: {
          'Content-Type': 'audio/x-raw, rate=16000, format=S16LE, channels=1, layout=interleaved',
          'save': 'true',
          'api_id': this.api_id,
          'api_key': this.api_key
        },
        body: data
      }).then(async (response: { status: number; json: () => any }) => {
        if (response.status === 200) {
          var rps = await response.json()
          this.chunk = []
          resolve(rps.hypotheses[0].transcript)
        }else {
          resolve({ error: this.responseErrorText });
        }
      }).catch((error) => reject(null))
    });

  }
}

let ASRservice = new ASRserviceClass();
export default ASRservice;
